#ifndef _CvsCheckOutDialog_h_
#define _CvsCheckOutDialog_h_

// $Id: CvsCheckOutDialog.h,v 1.9 2012/02/21 11:38:41 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file CvsCheckOutDialog.h
\brief QDialog used to checkout module from repository
\author Hugo Pereira
\version $Revision: 1.9 $
\date $Date: 2012/02/21 11:38:41 $
*/

#include "CustomDialog.h"
#include "AnimatedLineEditor.h"

#include <QtGui/QCheckBox>

class CvsCheckOutDialog: public CustomDialog
{

    Q_OBJECT

    public:

    //! constructor
    CvsCheckOutDialog( QWidget* parent );

    //! cvsroot
    void setCvsRoot( const QString& value )
    { rootEditor_->setText( value ); }

    //! cvsroot
    QString cvsRoot( void ) const
    { return rootEditor_->text(); }

    //! module name
    QList<QString> modules( void ) const;

    //! use different local name
    bool useLocalName( void ) const
    { return localNameEditor_->isEnabled(); }

    //! local name
    QString localName( void ) const
    { return localNameEditor_->text(); }

    private slots:

    //! check if multiple modules are present and update local editor consequently
    void _checkModules( const QString& );

    private:

    //! cvsroot editor
    AnimatedLineEditor* rootEditor_;

    //! module name editor
    AnimatedLineEditor* moduleEditor_;

    //! use local name
    QCheckBox* localNameCheckBox_;

    //! local name checkbox state
    bool state_;

    //! local name editor
    AnimatedLineEditor* localNameEditor_;

};

#endif
