// $Id: CvsCommandDialog.cpp,v 1.10 2012/10/18 14:13:10 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "CvsCommandDialog.h"

#include "ColumnSelectionMenu.h"
#include "ColumnSortingMenu.h"
#include "ContextMenu.h"
#include "Icons.h"
#include "IconEngine.h"
#include "TreeView.h"

#include <QtGui/QHeaderView>
#include <QtGui/QLayout>
#include <QtGui/QShortcut>

//____________________________________________________________
CvsCommandDialog::CvsCommandDialog( QWidget* parent ):
    CustomDialog( parent, CloseButton )
{

    Debug::Throw( "CvsCommandDialog::CvsCommandDialog.\n" );
    setWindowTitle( "Commands - Cvswatch" );
    setOptionName( "CVS_COMMANDS_DIALOG" );

    // custom margins
    layout()->setMargin(0);
    layout()->setSpacing(0);
    buttonLayout().setMargin(5);

    // main widget
    list_ = new TreeView( this );
    list_->setModel( &model_ );
    list_->setSortingEnabled( true );
    list_->setOptionName( "CVS_COMMAND_LIST" );
    list_->header()->hide();
    mainLayout().addWidget( list_ );

    // context menu
    QMenu* menu( new ContextMenu( list_ ) );
    menu->addMenu( new ColumnSortingMenu( menu, list_ ) );
    menu->addMenu( new ColumnSelectionMenu( menu, list_ ) );

    // ok button
    connect( &okButton(), SIGNAL( pressed( void ) ), SLOT( close( void ) ) );

    // close accelerator
    new QShortcut( QKeySequence::Close, this, SLOT( close() ) );

}

//_____________________________________________________________
void CvsCommandDialog::closeEvent( QCloseEvent* event )
{
    Debug::Throw( "CvsCommandDialog::closeEvent.\n" );
    emit dialogHidden();
    return CustomDialog::closeEvent( event );
}
