
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file CvsCommitDialog.cpp
\brief QDialog used to commit selected files
\author Hugo Pereira
\version $Revision: 1.16 $
\date $Date: 2011/11/15 15:33:09 $
*/

#include "TextEditor.h"
#include "CvsCommitDialog.h"
#include "TreeView.h"

#include <QtGui/QLabel>

//____________________________________________________________________________
QString CvsCommitDialog::savedComments_;

//____________________________________________________________________________
CvsCommitDialog::CvsCommitDialog( QWidget* parent, const FileInfo& path ):
    FileSelectionDialog( parent )
{

    Debug::Throw( "CvsCommitDialog::CvsCommitDialog.\n" );

    // insert path in list
    _model().add( path );
    _list().selectionModel()->select( _model().index( path ), QItemSelectionModel::SelectCurrent|QItemSelectionModel::Rows );

    // comments editor
    _workLayout().addWidget( new QLabel( "Comments: ", this ) );
    _workLayout().addWidget( editor_ = new TextEditor( this ), 1 );
    editor().setWrapFromOptions( false );
    editor().wrapModeAction().setChecked( true );
    editor().setAcceptRichText( false );
    editor().setPlainText( savedComments_ );

    okButton().setText( "&Commit" );
    okButton().setToolTip( "Commit selected files to the repository" );
    connect( &okButton(), SIGNAL( clicked() ), SLOT( _saveComments() ) );
    okButton().setFocus();
    adjustSize();
}

//____________________________________________________________________________
CvsCommitDialog::CvsCommitDialog( QWidget* parent, const FileInfoModel::List& files ):
    FileSelectionDialog( parent, files )
{

    Debug::Throw( "CvsCommitDialog::CvsCommitDialog.\n" );

    // comments editor
    _workLayout().addWidget( new QLabel( "Comments: ", this ) );
    _workLayout().addWidget( editor_ = new TextEditor( this ), 1 );
    editor().setWrapFromOptions( false );
    editor().wrapModeAction().setChecked( true );
    editor().setAcceptRichText( false );
    editor().setPlainText( savedComments_ );

    okButton().setText( "&Commit" );
    okButton().setToolTip( "Commit selected files to the repository" );
    connect( &okButton(), SIGNAL( clicked() ), SLOT( _saveComments() ) );
    adjustSize();
}

//____________________________________________________________________________
void CvsCommitDialog::_saveComments( void )
{
    Debug::Throw( "CvsCommitDialog::_saveComments.\n" );
    savedComments_ = editor().toPlainText();
}
