/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
  \file CvsRemoveDialog.cpp
  \brief QDialog used to commit selected files
  \author Hugo Pereira
  \version $Revision: 1.13 $
  \date $Date: 2011/11/15 15:33:09 $
*/

#include <QLabel>
#include <QGroupBox>
#include <QButtonGroup>

#include "CvsRemoveDialog.h"



//____________________________________________________________________________
CvsRemoveDialog::CvsRemoveDialog( QWidget* parent, const FileInfoModel::List& files ):
  FileSelectionDialog( parent, files )
{

  Debug::Throw( "CvsRemoveDialog::CvsRemoveDialog.\n" );

  _workLayout().addWidget( new QLabel( "", this ) );

  // action box
  QGroupBox* box = new QGroupBox( "Options", this );
  _workLayout().addWidget( box );
  QVBoxLayout *layout( new QVBoxLayout() );
  box->setLayout( layout );
  layout->setMargin(5);
  layout->setSpacing(5);

  QButtonGroup* group = new QButtonGroup( this );
  group->setExclusive( true );

  layout->addWidget( remove_from_disk_ = new QRadioButton( "Remove files from disk", box ) );
  group->addButton( remove_from_disk_ );
  remove_from_disk_->setToolTip( "Delete file from disk prior to removing them from the repository" );

  QRadioButton* radio_button;
  layout->addWidget( radio_button = new QRadioButton( "Rename files on disk", box ) );
  group->addButton( radio_button );
  radio_button->setToolTip( "Rename file from disk prior to removing them from the repository" );

  layout->addStretch(1);

  okButton().setText( "&Remove" );
  okButton().setToolTip( "Remove selected files from the repository. \nNote that the files must be removed/renamed from disk first" );
  okButton().setFocus();
  adjustSize();

}
