#ifndef FileInfoCache_h
#define FileInfoCache_h

// $Id: FileInfoCache.h,v 1.6 2012/02/21 11:38:42 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file    FileInfoCache.h
\brief   store list of file info and cvs information. Used for cache.
\author  Hugo Pereira
\version $Revision: 1.6 $
\date    $Date: 2012/02/21 11:38:42 $
*/

#include "Counter.h"
#include "FileInfo.h"
#include "File.h"

//! store list of file info and cvs information. Used for cache.
class FileInfoCache: public FileInfo::List, public Counter
{

    public:

    //! constructor
    FileInfoCache():
        Counter( "FileInfoCache" )
    {}

    //! constructor from Dom element
    FileInfoCache( const QDomElement& );

    //! write to dom element
    QDomElement domElement( QDomDocument& parent ) const;

    //! get all entries matching a path
    FileInfoCache findAll( File ) const;

    //! merge with cache
    void merge( const FileInfoCache& cache );

    //! update an existing entry or add, if not found
    /*! return true if added */
    bool insert( const FileInfo& );

    //! maximum size
    FileInfoCache& setMaximumSize( int size )
    {
        maxSize_ = size;
        return truncate();
    }

    //! truncate cache to maximum size
    FileInfoCache& truncate( void );

    //! remove
    void remove( const FileInfo& info )
    {
        int index(-1);
        while( ( index  = indexOf( info ) ) >= 0 )
        { removeAt( index ); }
        return;
    }

    private:

    //! maximum cache size. Negative means no limit. 0 means, cache disabled.
    int maxSize_;

};

#endif
