// $Id: FileInformationDialog.cpp,v 1.1 2012/11/19 10:54:42 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "FileInformationDialog.h"

//_________________________________________________________
FileInformationDialog::FileInformationDialog( QWidget* parent, const FileInfo& fileInfo ):
    BaseFileInformationDialog( parent )
{
    Debug::Throw( "FileInformationDialog::FileInformationDialog.\n" );

    // file name
    const File& file( fileInfo.file() );
    setWindowTitle( file.localName() + " - Qftp" );

    setFile( file.localName() );
    setPath( file.path() );

    // type
    setType( fileInfo.typeString() );

    // size
    if( fileInfo.isDocument() && !fileInfo.isLink() )
    { setSize( fileInfo.size() ); }

    // time stamps
    if( fileInfo.isLocal() )
    {
        setCreated( file.created() );
        setAccessed( file.lastAccessed() );
    }

    setModified( fileInfo.lastModified() );

    // cvs status
    setCustomValue(
        addRow( "Status:" ),
        fileInfo.statusString() );

    // permissions
    if( fileInfo.isLocal() )
    { setPermissions( fileInfo.permissions() ); }

    setUser( fileInfo.user() );
    setGroup( fileInfo.group() );

    adjustSize();

}
