// $Id: LogDialog.cpp,v 1.4 2012/09/29 16:30:13 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "LogDialog.h"
#include "LogWidget.h"
#include "Singleton.h"
#include "XmlOptions.h"

#include <QtGui/QLayout>
#include <QtGui/QShortcut>

//____________________________________________________________
const QString LogDialog::VERBOSITY_LOW( "low" );
const QString LogDialog::VERBOSITY_HIGH( "high" );

//____________________________________________________________
LogDialog::LogDialog( QWidget* parent ):
    CustomDialog( parent, CloseButton )
{

    Debug::Throw( "LogDialog::LogDialog.\n" );
    setWindowTitle( "Log Information - Cvswatch" );
    setOptionName( "LOG_DIALOG" );

    // custom margins
    layout()->setMargin(0);
    layout()->setSpacing(0);
    buttonLayout().setMargin(5);

    // editor
    editor_ = new LogWidget( this );
    editor_->setOptionName( "LOG_WIDGET" );
    mainLayout().addWidget( editor_ );

    // configuration
    connect( Singleton::get().application(), SIGNAL( configurationChanged() ), SLOT( _updateConfiguration() ) );

    // actions
    QActionGroup *group = new QActionGroup( this );
    group->setExclusive( true );
    connect( group, SIGNAL( triggered( QAction* ) ), SLOT( _changeVerbosity( QAction* ) ) );

    addAction( verbosityLowAction_ = new QAction( VERBOSITY_LOW, this ) );
    group->addAction( verbosityLowAction_ );
    verbosityLowAction_->setCheckable( true );

    addAction( verbosityHighAction_ = new QAction( VERBOSITY_HIGH, this ) );
    group->addAction( verbosityHighAction_ );
    verbosityHighAction_->setCheckable( true );

    _updateConfiguration();

    // ok button
    connect( &okButton(), SIGNAL( pressed( void ) ), SLOT( close( void ) ) );

    // close accelerator
    new QShortcut( QKeySequence::Close, this, SLOT( close() ) );

}

//_____________________________________________________________
void LogDialog::closeEvent( QCloseEvent* event )
{
    Debug::Throw( "LogDialog::closeEvent.\n" );
    emit dialogHidden();
    return CustomDialog::closeEvent( event );
}

//_____________________________________________________________
void LogDialog::_updateConfiguration( void )
{

    Debug::Throw( "LogDialog::_updateConfiguration.\n" );

    if( XmlOptions::get().raw( "VERBOSITY" ) == VERBOSITY_LOW )
    {

        editor().setVerbosity( CvsInterface::LOW );
        verbosityLowAction_->setChecked( true );

    } else if( XmlOptions::get().raw( "VERBOSITY" ) == VERBOSITY_HIGH ) {

        editor().setVerbosity( CvsInterface::HIGH );
        verbosityHighAction_->setChecked( true );

    }

}

//_____________________________________________________________
void LogDialog::_changeVerbosity( QAction* action )
{

    Debug::Throw( "LogDialog::_changeVerbosity.\n" );
    if( action == verbosityLowAction_ )
    {

        XmlOptions::get().set( "VERBOSITY", VERBOSITY_LOW ) ;
        editor().setVerbosity( CvsInterface::LOW );

    } else if( action == verbosityHighAction_ ) {

        editor().setVerbosity( CvsInterface::HIGH );
        XmlOptions::get().set( "VERBOSITY", VERBOSITY_HIGH ) ;

    }

}
