// $Id: Menu.cpp,v 1.41 2012/12/17 11:33:56 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Application.h"
#include "Debug.h"
#include "DebugMenu.h"
#include "DefaultHelpText.h"
#include "FileList.h"
#include "FileSelectionFrame.h"
#include "HelpText.h"
#include "HelpManager.h"
#include "LogDialog.h"
#include "MainWindow.h"
#include "Menu.h"
#include "RecentFilesMenu.h"
#include "Singleton.h"
#include "XmlOptions.h"
#include "Util.h"
#include "ViewModeMenu.h"

//__________________________________________________
Menu::Menu( QWidget* parent ):
    QMenuBar( parent ),
    Counter( "Menu" )
{

    Debug::Throw( "Menu::Menu" );

    // generic menu
    QMenu *menu;

    Application& application( *Singleton::get().application<Application>() );
    MainWindow& mainwindow( *static_cast<MainWindow*>( window() ) );
    FileSelectionFrame& selectionframe( mainwindow.selectionFrame() );

    // create file menu
    menu = addMenu( "File" );
    menu->addAction( &mainwindow.openAction() );

    // open previous menu
    recentFilesMenu_ = new RecentFilesMenu( this, application.recentFiles() );
    connect( recentFilesMenu_, SIGNAL( fileSelected( FileRecord ) ), &mainwindow, SLOT( open( FileRecord ) ) );
    menu->addMenu( recentFilesMenu_ );

    menu->addAction( &mainwindow.reloadAction() );

    // quit button
    menu->addSeparator();
    menu->addAction( &application.closeAction() );

    // windows menu
    menu = addMenu( "Windows" );
    menu->addAction( &mainwindow.showLogDialogAction() );
    menu->addAction( &mainwindow.showCommandDialogAction() );

    // create preferences menu
    menu = addMenu( "Settings" );
    menu->addMenu( viewModeMenu_ = new ViewModeMenu( this ) );
    viewModeMenu_->setTitle( "View Mode" );

    QMenu* subMenu = menu->addMenu( "Log Verbosity" );
    subMenu->addAction( &mainwindow.logDialog().verbosityLowAction() );
    subMenu->addAction( &mainwindow.logDialog().verbosityHighAction() );
    menu->addSeparator();

    menu->addAction( &selectionframe.hiddenFilesAction() );
    menu->addSeparator();

    menu->addAction( &application.configurationAction() );

    // help manager
    BASE::HelpManager* help( new BASE::HelpManager( this ) );
    help->setWindowTitle( "Cvswatch Handbook" );
    help->install( helpText );
    help->install( BASE::helpText, false );

    // create help menu
    menu = addMenu( "Help" );
    menu->addAction( &help->displayAction() );
    menu->addSeparator();
    menu->addAction( &application.aboutAction() );
    menu->addAction( &application.aboutQtAction() );

    // debug menu
    #ifdef DEBUG
    menu->addSeparator();
    DebugMenu *debugMenu( new DebugMenu( this ) );
    debugMenu->setTitle( "Debug" );
    debugMenu->addAction( &help->dumpAction() );
    debugMenu->addAction( &mainwindow.fileInfoCacheAction() );
    debugMenu->addAction( &mainwindow.revisionCacheAction() );
    menu->addMenu( debugMenu );
    #endif

}
