
// $Id: Revision.cpp,v 1.15 2012/10/08 17:52:37 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
  \file  Revision.cpp
  \brief cvs file revision container
  \author Hugo Pereira
  \version $Revision: 1.15 $
  \date $Date: 2012/10/08 17:52:37 $
*/



#include "Revision.h"
#include "Str.h"
#include "XmlDef.h"
#include "XmlString.h"



//_________________________________________________________________
Revision::Revision( const QDomElement& element ):
  Counter( "Revision" )
{
  Debug::Throw( "Revision::Revision (dom) .\n" );

  // parse attributes
  QDomNamedNodeMap attributes( element.attributes() );
  for( unsigned int i=0; i<attributes.length(); i++ )
  {
    QDomAttr attribute( attributes.item( i ).toAttr() );
    if( attribute.isNull() ) continue;
    QString name( attribute.name() );
    QString value( attribute.value() );

    if( name == XML::NAME ) setName( XmlString( value ).toText() );
    else if( name == XML::AUTHOR ) setAuthor( XmlString( value ).toText() );
    else if( name == XML::TIME ) setTimeStamp( value.toInt() );
    else Debug::Throw(0) << "unrecognized attachment attribute: \"" << name << "\"\n";
  }

  // parse children elements
  for(QDomNode child_node = element.firstChild(); !child_node.isNull(); child_node = child_node.nextSibling() )
  {
    QDomElement child_element = child_node.toElement();
    if( child_element.tagName() == XML::COMMENTS )
    { setComments( XmlString( child_element.text() ).toText() ); }
    else Debug::Throw(0) << "unrecognized child " << child_element.tagName() << ".\n";
  }

}

//_________________________________________________________________
QDomElement Revision::domElement( QDomDocument& parent ) const
{
  Debug::Throw( "Revision::domElement\n" );

  QDomElement out( parent.createElement( XML::REVISION ) );
  out.setAttribute( XML::NAME, XmlString( name() ).toXml() );
  out.setAttribute( XML::AUTHOR, XmlString( author() ).toXml() );
  out.setAttribute( XML::TIME, QString().setNum( timeStamp() ) );

  if( comments().size())
  {
    out.
      appendChild( parent.createElement(  XML::COMMENTS ) ).
      appendChild( parent.createTextNode( XmlString( comments() ).toXml() ) );
  }

  return out;

}

//_________________________________________________________________
void Revision::setName( QString name )
{
  Debug::Throw( "Revision::setName.\n" );
  QString local( name );
  local.replace( ".", " " );
  QTextStream in( &local );

  revision_.clear();
  int i = 0;
  while( in.status() == QTextStream::Ok )
  {
    in >> i;
    if( in.status() == QTextStream::Ok ) revision_ << i;
  }

  name_ = name;
  return;
}

//_________________________________________________________________
void Revision::setTimeStamp( QString value )
{
  Debug::Throw( "Revision::setTimeStamp.\n" );

  // need to convert into a time stamp
  TimeStamp time_stamp;
  QTextStream what( &value );
  QString date_string, time_string;

  what >> date_string >> time_string;
  date_string = date_string.replace( "/", " " );
  date_string = date_string.replace( "-", " " );
  time_string = time_string.replace( ":", " " );

  QTextStream date_stream( &date_string );
  int year, month, day;
  date_stream >> year >> month >> day;

  QTextStream time_stream( &time_string );
  int hour, minutes, seconds;
  time_stream >> hour >> minutes >> seconds;

  time_stamp.setYear( year );
  time_stamp.setMonth( month );
  time_stamp.setDay( day );

  time_stamp.setHours( hour );
  time_stamp.setMinutes( minutes );
  time_stamp.setSeconds( seconds );
  time_stamp.makeTime();

  setTimeStamp( time_stamp );

}
