#ifndef Revision_h
#define Revision_h

// $Id: Revision.h,v 1.17 2012/02/21 08:58:44 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Counter.h"
#include "File.h"
#include "TimeStamp.h"

#include <QtXml/QDomDocument>
#include <QtXml/QDomElement>
#include <QtCore/QList>
#include <QtCore/QPair>

//! cvs log version info container
class Revision: public Counter
{

    public:

    //! constructor
    Revision( void ):
        Counter( "Revision" )
    {}

    //! constructor from dom element
    Revision( const QDomElement& element );

    //! less than operator
    bool operator < ( const Revision& rev ) const
    { return revision_ < rev.revision_; }

    //! equal to operator
    bool operator == ( const Revision& rev ) const
    {
        return
            timeStamp() == rev.timeStamp() &&
            revision_ == rev.revision_;
    }

    //! create domElement
    QDomElement domElement( QDomDocument& parent ) const;

    //! revision name
    const QString& name( void ) const
    { return name_; }

    //! revision name
    void setName( QString value );

    //! timestamp
    const TimeStamp& timeStamp( void ) const
    { return timestamp_;  }

    //! timestamp (from string)
    void setTimeStamp( QString );

    //! timestamp
    void setTimeStamp( const TimeStamp& stamp )
    { timestamp_ = stamp; }

    //! author
    const QString& author( void ) const
    { return author_; }

    //! author
    void setAuthor( const QString& value )
    { author_ = value; }

    //! comments
    const QString& comments( void ) const
    { return comments_; }

    //! comments
    void setComments( const QString& value )
    { comments_ = value; }

    //! append comments
    void appendComments( const QString& value )
    { comments_ += value; }

    //! clear comments
    void clearComments( void )
    { comments_ = ""; }

    //! revision list
    class List: public QList<Revision>, public Counter
    {
        public:

        //! constructor
        List( TimeStamp creation = TimeStamp::now() ):
            Counter( "Revision::List" ),
            creation_( creation )
        {}

        //! creation timestamp
        void setCreation( const TimeStamp& stamp )
        { creation_ = stamp; }

        //! creation timestamp
        const TimeStamp& created( void ) const
        { return creation_; }

        private:

        //! creation timestamp
        TimeStamp creation_;

    };

    private:

    //! revision name
    QString name_;

    class RevisionList: public QList<int>
    {
        public:

        bool operator < (const RevisionList& other ) const
        {
            for( int i = 0; i < size() && i < other.size(); ++i )
            { if( at(i) != other.at(i) ) return at(i)<other.at(i); }

            return size() < other.size();
        }

    };

    //! revision string. One integer per number in the revision
    /*! it is used internally to compare two revisions */
    RevisionList revision_;

    //! time stamp
    TimeStamp timestamp_;

    //! author
    QString author_;

    //! comments
    QString comments_;

};

//! revision pair (needed for RevisionCacheModel)
class RevisionPair: public QPair<File, Revision>
{

    public:

    //! constructor
    RevisionPair( void )
    {}

    //! constructor
    RevisionPair( const File& file, const Revision& revision ):
        QPair<File, Revision>( file, revision )
    {}

    //! destructor
    virtual ~RevisionPair( void )
    {}

    //! child operator
    bool isChild( const RevisionPair& other ) const
    { return first == other.first; }

//     //! less than operator
//     bool operator < (const RevisionPair& other ) const
//     {
//         if( first != other.first ) return first < other.first;
//         else return second < other.second;
//     }

};


#endif
