// $Id: RevisionCacheModel.cpp,v 1.8 2012/11/22 22:25:31 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file    RevisionCacheModel.h
\brief   Revision model. Stores job information for display in lists
\author  Hugo Pereira
\version $Revision: 1.8 $
\date    $Date: 2012/11/22 22:25:31 $
*/

#include "RevisionCacheModel.h"
#include "Singleton.h"
#include "XmlOptions.h"

//_______________________________________________
const QString RevisionCacheModel::columnTitles_[ RevisionCacheModel::nColumns ] =
{
    "File",
    "Path",
    "Revision",
    "Date",
    "Author"
};

//_______________________________________________________________
RevisionCacheModel::RevisionCacheModel( QObject* parent ):
    TreeModel<RevisionPair>( parent ),
    Counter( "RevisionCacheModel" )
{ Debug::Throw( "RevisionCacheModel::RevisionCacheModel.\n" ); }


//__________________________________________________________________
QVariant RevisionCacheModel::data( const QModelIndex& index, int role ) const
{

    // check index, role and column
    if( !index.isValid() ) return QVariant();
    if( role == Qt::DisplayRole )
    {

        // retrieve associated command
        const RevisionPair& revision( _find( index.internalId() ).get() );

        switch( index.column() )
        {
            case FILE: return revision.first.localName();
            case PATH: return revision.first.path();
            case REVISION: return revision.second.name();
            case DATE: return revision.second.timeStamp().toString();
            case AUTHOR: return revision.second.author();
            default: return QVariant();
        }

    }

    return QVariant();

}

//__________________________________________________________________
QVariant RevisionCacheModel::headerData(int section, Qt::Orientation orientation, int role) const
{

    if(
        orientation == Qt::Horizontal &&
        role == Qt::DisplayRole &&
        section >= 0 &&
        section < int(nColumns) )
    { return columnTitles_[section]; }

    // return empty
    return QVariant();

}

//___________________________________________________________
bool RevisionCacheModel::SortFTor::operator() ( RevisionPair first, RevisionPair second ) const
{

    if( order_ == Qt::DescendingOrder ) std::swap( first, second );

    switch( type_ )
    {

        default:
        case FILE:
        return first.first.localName() < second.first.localName();
        break;

        case PATH:
        return first.first.path() < second.first.path();
        break;

        case REVISION:
        return first.second.name() < second.second.name();
        break;

        case DATE:
        return first.second.timeStamp() < second.second.timeStamp();
        break;

        case AUTHOR:
        return first.second.author() < second.second.author();
        break;

    }

    return true;

}
