#ifndef RevisionCacheModel_h
#define RevisionCacheModel_h

// $Id: RevisionCacheModel.h,v 1.4 2012/09/27 13:46:33 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Counter.h"
#include "Revision.h"
#include "TreeModel.h"

#include <QtGui/QColor>

//! Revision model. Stores job information for display in lists
class RevisionCacheModel : public TreeModel<RevisionPair>, public Counter
{

    public:

    //! constructor
    RevisionCacheModel( QObject* = 0 );

    //! destructor
    virtual ~RevisionCacheModel( void )
    {}

    //! number of columns
    enum { nColumns = 5 };

    //! column type enumeration
    enum ColumnType
    {
        FILE,
        PATH,
        REVISION,
        DATE,
        AUTHOR
    };

    //!@name methods reimplemented from base class
    //@{

    // return job for a given index
    virtual QVariant data( const QModelIndex&, int ) const;

    //! header data
    virtual QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole) const;

    //! number of columns for a given index
    virtual int columnCount( const QModelIndex& = QModelIndex() ) const
    { return nColumns; }

    //@}

    protected:

    //! sorting
    virtual void _sort( int column, Qt::SortOrder order = Qt::AscendingOrder )
    { _root().sort( SortFTor( column, order ) ); }

    private:


    //! used to sort IconCaches
    class SortFTor: public ItemModel::SortFTor
    {

        public:

        //! constructor
        SortFTor( const int& type, Qt::SortOrder order = Qt::AscendingOrder ):
            ItemModel::SortFTor( type, order )
            {}

        //! prediction
        bool operator() ( const Item& first, const Item& second ) const
        { return (*this)( first.get(), second.get() ); }

        //! prediction
        bool operator() ( RevisionPair, RevisionPair ) const;

    };

    //! list column names
    static const QString columnTitles_[nColumns];

};

#endif
