// $Id: RevisionModel.cpp,v 1.19 2012/11/22 22:25:31 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Debug.h"
#include "RevisionModel.h"
#include "TimeStamp.h"

//_______________________________________________
const QString RevisionModel::columnTitles_[ RevisionModel::nColumns ] =
{
    "Rev",
    "Date",
    "Author",
    "Comment"
};

//_______________________________________________________________
RevisionModel::RevisionModel( QObject* parent ):
    ListModel<Revision>( parent ),
    Counter( "RevisionModel" )
{

    Debug::Throw( "RevisionModel::RevisionModel.\n" );

}

//__________________________________________________________________
QVariant RevisionModel::data( const QModelIndex& index, int role ) const
{

    // check index, role and column
    if( !index.isValid() ) return QVariant();

    // retrieve associated command
    const Revision& revision( get()[index.row()] );

    // return text associated to command and column
    if( role == Qt::DisplayRole ) {

        switch( index.column() )
        {
            case REVISION: return revision.name();
            case DATE: return revision.timeStamp().toString();
            case AUTHOR: return revision.author();
            case COMMENT:
            return revision.comments().section( '\n', 0, 0, QString::SectionSkipEmpty );

            default: return QVariant();
        }
    }

    return QVariant();

}

//__________________________________________________________________
QVariant RevisionModel::headerData(int section, Qt::Orientation orientation, int role) const
{

    if(
        orientation == Qt::Horizontal &&
        role == Qt::DisplayRole &&
        section >= 0 &&
        section < nColumns )
    { return columnTitles_[section]; }

    // return empty
    return QVariant();

}

//____________________________________________________________
void RevisionModel::_sort( int column, Qt::SortOrder order )
{
    Debug::Throw() << "RevisionModel::sort - column: " << column << " order: " << order << endl;
    std::sort( _get().begin(), _get().end(), SortFTor( (ColumnType) column, order ) );
}

//________________________________________________________
bool RevisionModel::SortFTor::operator () ( Revision first, Revision second ) const
{

    if( order_ == Qt::DescendingOrder ) std::swap( first, second );

    switch( type_ )
    {

        case DATE: return first.timeStamp() < second.timeStamp();
        case AUTHOR: return first.author() < second.author();
        default:
        case REVISION: return first < second;
    }

}
